# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/clarifai/api/concept.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from clarifai.rest.grpc.proto.clarifai.api import common_pb2 as proto_dot_clarifai_dot_api_dot_common__pb2
from clarifai.rest.grpc.proto.clarifai.api.status import status_pb2 as proto_dot_clarifai_dot_api_dot_status_dot_status__pb2
from clarifai.rest.grpc.proto.clarifai.api.utils import extensions_pb2 as proto_dot_clarifai_dot_api_dot_utils_dot_extensions__pb2
from clarifai.rest.grpc.proto.clarifai.utils.pagination import pagination_pb2 as proto_dot_clarifai_dot_utils_dot_pagination_dot_pagination__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/clarifai/api/concept.proto',
  package='clarifai.api',
  syntax='proto3',
  serialized_pb=_b('\n proto/clarifai/api/concept.proto\x12\x0c\x63larifai.api\x1a\x1fproto/clarifai/api/common.proto\x1a&proto/clarifai/api/status/status.proto\x1a)proto/clarifai/api/utils/extensions.proto\x1a\x30proto/clarifai/utils/pagination/pagination.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa5\x01\n\x07\x43oncept\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1a\n\x05value\x18\x03 \x01(\x02\x42\x0b\xd5\xb5\x18\x00\x00\x80?\x80\xb5\x18\x01\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08language\x18\x05 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x06 \x01(\t\x12\x12\n\ndefinition\x18\x07 \x01(\t\"d\n\x0c\x43onceptCount\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12:\n\x12\x63oncept_type_count\x18\x03 \x01(\x0b\x32\x1e.clarifai.api.ConceptTypeCount\"6\n\x10\x43onceptTypeCount\x12\x10\n\x08positive\x18\x01 \x01(\r\x12\x10\n\x08negative\x18\x02 \x01(\r\"X\n\x11GetConceptRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x12\n\nconcept_id\x18\x02 \x01(\t\"f\n\x13ListConceptsRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x0c\n\x04page\x18\x02 \x01(\r\x12\x10\n\x08per_page\x18\x03 \x01(\r\"\xa2\x01\n\x1bPostConceptsSearchesRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x31\n\rconcept_query\x18\x02 \x01(\x0b\x32\x1a.clarifai.api.ConceptQuery\x12\x1f\n\npagination\x18\x03 \x01(\x0b\x32\x0b.Pagination\".\n\x0c\x43onceptQuery\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\t\"o\n\x13PostConceptsRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\'\n\x08\x63oncepts\x18\x02 \x03(\x0b\x32\x15.clarifai.api.Concept\"\x80\x01\n\x14PatchConceptsRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\'\n\x08\x63oncepts\x18\x02 \x03(\x0b\x32\x15.clarifai.api.Concept\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\t\"j\n\x17GetConceptCountsRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x0c\n\x04page\x18\x02 \x01(\r\x12\x10\n\x08per_page\x18\x03 \x01(\r\"l\n\x15SingleConceptResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12&\n\x07\x63oncept\x18\x02 \x01(\x0b\x32\x15.clarifai.api.Concept\"r\n\x14MultiConceptResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12-\n\x08\x63oncepts\x18\x02 \x03(\x0b\x32\x15.clarifai.api.ConceptB\x04\x80\xb5\x18\x01\"\x82\x01\n\x19MultiConceptCountResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12\x38\n\x0e\x63oncept_counts\x18\x02 \x03(\x0b\x32\x1a.clarifai.api.ConceptCountB\x04\x80\xb5\x18\x01\x42$Z\x03\x61pi\xa2\x02\x04\x43\x41IP\xc2\x02\x01_\xca\x02\x11\x43larifai\\Internalb\x06proto3')
  ,
  dependencies=[proto_dot_clarifai_dot_api_dot_common__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_utils_dot_extensions__pb2.DESCRIPTOR,proto_dot_clarifai_dot_utils_dot_pagination_dot_pagination__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_CONCEPT = _descriptor.Descriptor(
  name='Concept',
  full_name='clarifai.api.Concept',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='clarifai.api.Concept.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='clarifai.api.Concept.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='clarifai.api.Concept.value', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\325\265\030\000\000\200?\200\265\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='clarifai.api.Concept.created_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language', full_name='clarifai.api.Concept.language', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='clarifai.api.Concept.app_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='definition', full_name='clarifai.api.Concept.definition', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=415,
)


_CONCEPTCOUNT = _descriptor.Descriptor(
  name='ConceptCount',
  full_name='clarifai.api.ConceptCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='clarifai.api.ConceptCount.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='clarifai.api.ConceptCount.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept_type_count', full_name='clarifai.api.ConceptCount.concept_type_count', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=417,
  serialized_end=517,
)


_CONCEPTTYPECOUNT = _descriptor.Descriptor(
  name='ConceptTypeCount',
  full_name='clarifai.api.ConceptTypeCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='positive', full_name='clarifai.api.ConceptTypeCount.positive', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='negative', full_name='clarifai.api.ConceptTypeCount.negative', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=519,
  serialized_end=573,
)


_GETCONCEPTREQUEST = _descriptor.Descriptor(
  name='GetConceptRequest',
  full_name='clarifai.api.GetConceptRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.GetConceptRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept_id', full_name='clarifai.api.GetConceptRequest.concept_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=663,
)


_LISTCONCEPTSREQUEST = _descriptor.Descriptor(
  name='ListConceptsRequest',
  full_name='clarifai.api.ListConceptsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.ListConceptsRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page', full_name='clarifai.api.ListConceptsRequest.page', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='per_page', full_name='clarifai.api.ListConceptsRequest.per_page', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=665,
  serialized_end=767,
)


_POSTCONCEPTSSEARCHESREQUEST = _descriptor.Descriptor(
  name='PostConceptsSearchesRequest',
  full_name='clarifai.api.PostConceptsSearchesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.PostConceptsSearchesRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept_query', full_name='clarifai.api.PostConceptsSearchesRequest.concept_query', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='clarifai.api.PostConceptsSearchesRequest.pagination', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=770,
  serialized_end=932,
)


_CONCEPTQUERY = _descriptor.Descriptor(
  name='ConceptQuery',
  full_name='clarifai.api.ConceptQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='clarifai.api.ConceptQuery.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language', full_name='clarifai.api.ConceptQuery.language', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=934,
  serialized_end=980,
)


_POSTCONCEPTSREQUEST = _descriptor.Descriptor(
  name='PostConceptsRequest',
  full_name='clarifai.api.PostConceptsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.PostConceptsRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concepts', full_name='clarifai.api.PostConceptsRequest.concepts', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=982,
  serialized_end=1093,
)


_PATCHCONCEPTSREQUEST = _descriptor.Descriptor(
  name='PatchConceptsRequest',
  full_name='clarifai.api.PatchConceptsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.PatchConceptsRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concepts', full_name='clarifai.api.PatchConceptsRequest.concepts', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='clarifai.api.PatchConceptsRequest.action', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1096,
  serialized_end=1224,
)


_GETCONCEPTCOUNTSREQUEST = _descriptor.Descriptor(
  name='GetConceptCountsRequest',
  full_name='clarifai.api.GetConceptCountsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.GetConceptCountsRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page', full_name='clarifai.api.GetConceptCountsRequest.page', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='per_page', full_name='clarifai.api.GetConceptCountsRequest.per_page', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1226,
  serialized_end=1332,
)


_SINGLECONCEPTRESPONSE = _descriptor.Descriptor(
  name='SingleConceptResponse',
  full_name='clarifai.api.SingleConceptResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.SingleConceptResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept', full_name='clarifai.api.SingleConceptResponse.concept', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1334,
  serialized_end=1442,
)


_MULTICONCEPTRESPONSE = _descriptor.Descriptor(
  name='MultiConceptResponse',
  full_name='clarifai.api.MultiConceptResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.MultiConceptResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concepts', full_name='clarifai.api.MultiConceptResponse.concepts', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1444,
  serialized_end=1558,
)


_MULTICONCEPTCOUNTRESPONSE = _descriptor.Descriptor(
  name='MultiConceptCountResponse',
  full_name='clarifai.api.MultiConceptCountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.MultiConceptCountResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept_counts', full_name='clarifai.api.MultiConceptCountResponse.concept_counts', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1561,
  serialized_end=1691,
)

_CONCEPT.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CONCEPTCOUNT.fields_by_name['concept_type_count'].message_type = _CONCEPTTYPECOUNT
_GETCONCEPTREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_LISTCONCEPTSREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_POSTCONCEPTSSEARCHESREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_POSTCONCEPTSSEARCHESREQUEST.fields_by_name['concept_query'].message_type = _CONCEPTQUERY
_POSTCONCEPTSSEARCHESREQUEST.fields_by_name['pagination'].message_type = proto_dot_clarifai_dot_utils_dot_pagination_dot_pagination__pb2._PAGINATION
_POSTCONCEPTSREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_POSTCONCEPTSREQUEST.fields_by_name['concepts'].message_type = _CONCEPT
_PATCHCONCEPTSREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_PATCHCONCEPTSREQUEST.fields_by_name['concepts'].message_type = _CONCEPT
_GETCONCEPTCOUNTSREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_SINGLECONCEPTRESPONSE.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_SINGLECONCEPTRESPONSE.fields_by_name['concept'].message_type = _CONCEPT
_MULTICONCEPTRESPONSE.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_MULTICONCEPTRESPONSE.fields_by_name['concepts'].message_type = _CONCEPT
_MULTICONCEPTCOUNTRESPONSE.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_MULTICONCEPTCOUNTRESPONSE.fields_by_name['concept_counts'].message_type = _CONCEPTCOUNT
DESCRIPTOR.message_types_by_name['Concept'] = _CONCEPT
DESCRIPTOR.message_types_by_name['ConceptCount'] = _CONCEPTCOUNT
DESCRIPTOR.message_types_by_name['ConceptTypeCount'] = _CONCEPTTYPECOUNT
DESCRIPTOR.message_types_by_name['GetConceptRequest'] = _GETCONCEPTREQUEST
DESCRIPTOR.message_types_by_name['ListConceptsRequest'] = _LISTCONCEPTSREQUEST
DESCRIPTOR.message_types_by_name['PostConceptsSearchesRequest'] = _POSTCONCEPTSSEARCHESREQUEST
DESCRIPTOR.message_types_by_name['ConceptQuery'] = _CONCEPTQUERY
DESCRIPTOR.message_types_by_name['PostConceptsRequest'] = _POSTCONCEPTSREQUEST
DESCRIPTOR.message_types_by_name['PatchConceptsRequest'] = _PATCHCONCEPTSREQUEST
DESCRIPTOR.message_types_by_name['GetConceptCountsRequest'] = _GETCONCEPTCOUNTSREQUEST
DESCRIPTOR.message_types_by_name['SingleConceptResponse'] = _SINGLECONCEPTRESPONSE
DESCRIPTOR.message_types_by_name['MultiConceptResponse'] = _MULTICONCEPTRESPONSE
DESCRIPTOR.message_types_by_name['MultiConceptCountResponse'] = _MULTICONCEPTCOUNTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Concept = _reflection.GeneratedProtocolMessageType('Concept', (_message.Message,), dict(
  DESCRIPTOR = _CONCEPT,
  __module__ = 'proto.clarifai.api.concept_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.Concept)
  ))
_sym_db.RegisterMessage(Concept)

ConceptCount = _reflection.GeneratedProtocolMessageType('ConceptCount', (_message.Message,), dict(
  DESCRIPTOR = _CONCEPTCOUNT,
  __module__ = 'proto.clarifai.api.concept_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.ConceptCount)
  ))
_sym_db.RegisterMessage(ConceptCount)

ConceptTypeCount = _reflection.GeneratedProtocolMessageType('ConceptTypeCount', (_message.Message,), dict(
  DESCRIPTOR = _CONCEPTTYPECOUNT,
  __module__ = 'proto.clarifai.api.concept_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.ConceptTypeCount)
  ))
_sym_db.RegisterMessage(ConceptTypeCount)

GetConceptRequest = _reflection.GeneratedProtocolMessageType('GetConceptRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCONCEPTREQUEST,
  __module__ = 'proto.clarifai.api.concept_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.GetConceptRequest)
  ))
_sym_db.RegisterMessage(GetConceptRequest)

ListConceptsRequest = _reflection.GeneratedProtocolMessageType('ListConceptsRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTCONCEPTSREQUEST,
  __module__ = 'proto.clarifai.api.concept_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.ListConceptsRequest)
  ))
_sym_db.RegisterMessage(ListConceptsRequest)

PostConceptsSearchesRequest = _reflection.GeneratedProtocolMessageType('PostConceptsSearchesRequest', (_message.Message,), dict(
  DESCRIPTOR = _POSTCONCEPTSSEARCHESREQUEST,
  __module__ = 'proto.clarifai.api.concept_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.PostConceptsSearchesRequest)
  ))
_sym_db.RegisterMessage(PostConceptsSearchesRequest)

ConceptQuery = _reflection.GeneratedProtocolMessageType('ConceptQuery', (_message.Message,), dict(
  DESCRIPTOR = _CONCEPTQUERY,
  __module__ = 'proto.clarifai.api.concept_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.ConceptQuery)
  ))
_sym_db.RegisterMessage(ConceptQuery)

PostConceptsRequest = _reflection.GeneratedProtocolMessageType('PostConceptsRequest', (_message.Message,), dict(
  DESCRIPTOR = _POSTCONCEPTSREQUEST,
  __module__ = 'proto.clarifai.api.concept_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.PostConceptsRequest)
  ))
_sym_db.RegisterMessage(PostConceptsRequest)

PatchConceptsRequest = _reflection.GeneratedProtocolMessageType('PatchConceptsRequest', (_message.Message,), dict(
  DESCRIPTOR = _PATCHCONCEPTSREQUEST,
  __module__ = 'proto.clarifai.api.concept_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.PatchConceptsRequest)
  ))
_sym_db.RegisterMessage(PatchConceptsRequest)

GetConceptCountsRequest = _reflection.GeneratedProtocolMessageType('GetConceptCountsRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCONCEPTCOUNTSREQUEST,
  __module__ = 'proto.clarifai.api.concept_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.GetConceptCountsRequest)
  ))
_sym_db.RegisterMessage(GetConceptCountsRequest)

SingleConceptResponse = _reflection.GeneratedProtocolMessageType('SingleConceptResponse', (_message.Message,), dict(
  DESCRIPTOR = _SINGLECONCEPTRESPONSE,
  __module__ = 'proto.clarifai.api.concept_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.SingleConceptResponse)
  ))
_sym_db.RegisterMessage(SingleConceptResponse)

MultiConceptResponse = _reflection.GeneratedProtocolMessageType('MultiConceptResponse', (_message.Message,), dict(
  DESCRIPTOR = _MULTICONCEPTRESPONSE,
  __module__ = 'proto.clarifai.api.concept_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.MultiConceptResponse)
  ))
_sym_db.RegisterMessage(MultiConceptResponse)

MultiConceptCountResponse = _reflection.GeneratedProtocolMessageType('MultiConceptCountResponse', (_message.Message,), dict(
  DESCRIPTOR = _MULTICONCEPTCOUNTRESPONSE,
  __module__ = 'proto.clarifai.api.concept_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.MultiConceptCountResponse)
  ))
_sym_db.RegisterMessage(MultiConceptCountResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z\003api\242\002\004CAIP\302\002\001_\312\002\021Clarifai\\Internal'))
_CONCEPT.fields_by_name['value'].has_options = True
_CONCEPT.fields_by_name['value']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\325\265\030\000\000\200?\200\265\030\001'))
_MULTICONCEPTRESPONSE.fields_by_name['concepts'].has_options = True
_MULTICONCEPTRESPONSE.fields_by_name['concepts']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001'))
_MULTICONCEPTCOUNTRESPONSE.fields_by_name['concept_counts'].has_options = True
_MULTICONCEPTCOUNTRESPONSE.fields_by_name['concept_counts']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001'))
# @@protoc_insertion_point(module_scope)



import base64
import logging
import os
import time
import unittest
import uuid
from io import BytesIO

from clarifai.rest import ApiClient, ApiError, ClarifaiApp, Geo, GeoPoint
from clarifai.rest import Image as ClarifaiImage
from clarifai.rest import UserError

urls = [
    "https://samples.clarifai.com/metro-north.jpg",
    "https://samples.clarifai.com/wedding.jpg",
    "https://samples.clarifai.com/facebook.png",
    "https://samples.clarifai.com/dog.tiff",
    "https://samples.clarifai.com/penguin.bmp",
]


def _data_filename(filename):
  return os.path.join(os.path.dirname(os.path.abspath(__file__)), 'data', filename)


class TestImages(unittest.TestCase):
  _multiprocess_can_split_ = True
  to_cleanup = []

  @classmethod
  def setUpClass(cls):
    cls.api = ApiClient(log_level=logging.WARN)
    cls.app = ClarifaiApp(log_level=logging.WARN)

  @classmethod
  def tearDownClass(cls):
    """ Cleanup """

  def test_init_images(self):
    """ initialize Image object in different ways """
    toddler_flowers_file_path = _data_filename('toddler-flowers.jpeg')

    img1 = ClarifaiImage(url=urls[2])
    with open(toddler_flowers_file_path, 'rb') as f:
      img2 = ClarifaiImage(file_obj=f)
    img3 = ClarifaiImage(filename=toddler_flowers_file_path)

    with open(toddler_flowers_file_path, 'rb') as f:
      toddler_flowers_file_bytes = f.read()
    toddler_flowers_base64_bytes = base64.b64encode(toddler_flowers_file_bytes)
    img4 = ClarifaiImage(base64=toddler_flowers_base64_bytes)

    # init with crops
    img1 = ClarifaiImage(url=urls[2], crop=[0.1, 0.3, 0.5, 0.7])

    f = open(toddler_flowers_file_path, 'rb')
    img2 = ClarifaiImage(file_obj=f, crop=[0.1, 0.3, 0.5, 0.7])
    f.close()

    img3 = ClarifaiImage(filename=toddler_flowers_file_path, crop=[0.1, 0.3, 0.5, 0.7])

    img4 = ClarifaiImage(base64=toddler_flowers_base64_bytes, crop=[0.1, 0.3, 0.5, 0.7])

    self.assertListEqual(img1.crop, [0.1, 0.3, 0.5, 0.7])
    self.assertListEqual(img2.crop, [0.1, 0.3, 0.5, 0.7])
    self.assertListEqual(img3.crop, [0.1, 0.3, 0.5, 0.7])
    self.assertListEqual(img4.crop, [0.1, 0.3, 0.5, 0.7])

    # init with urls with spaces
    img5 = ClarifaiImage(url=' ' + urls[2])
    self.assertEqual(img5.url, urls[2])

    img6 = ClarifaiImage(url=' ' + urls[2] + ' ')
    self.assertEqual(img6.url, urls[2])

  def test_get_all_inputs(self):
    """ test get all inputs """

    # try to iterate all inputs
    ccount = 0
    for input in self.app.inputs.get_all():
      self.assertTrue(isinstance(input, ClarifaiImage))
      ccount += 1
      if ccount >= 50:
        break

    self.assertGreaterEqual(ccount, 0)

  def test_get_inputs_by_page(self):
    """ test get all images """

    # test the by_page() fetcher on first page
    for image in self.app.inputs.get_by_page():
      self.assertTrue(isinstance(image, ClarifaiImage))

  def test_attributes_via_create_image(self):
    """ test attribute after image creation """
    image = self.app.inputs.create_image_from_url(url=urls[0], allow_duplicate_url=True)
    self.assertEqual(image.url, urls[0])
    self.assertEqual(len(image.input_id) in [22, 32], True)
    # FIXME(robert): fix this after the backend fix
    # self.assertTrue(image.allow_dup_url)
    self.assertIsNone(image.geo)
    self.assertIsNone(image.file_obj)
    self.assertIsNone(image.concepts)
    self.assertIsNone(image.not_concepts)

    image_id = image.input_id

    img = self.app.inputs.get(image_id)
    self.assertEqual(image_id, img.input_id)
    # FIXME(robert): fix this after the backend fix
    # self.assertTrue(image.allow_dup_url)
    self.assertIsNone(image.geo)
    self.assertIsNone(image.file_obj)
    self.assertIsNone(image.concepts)
    self.assertIsNone(image.not_concepts)

  def test_post_image_with_url_spaces(self):
    """ add image from url with leading or trailing spaces """

    image = self.app.inputs.create_image_from_url(url=' ' + urls[0], allow_duplicate_url=True)
    self.assertEqual(image.url, urls[0])
    self.assertEqual(len(image.input_id) in [22, 32], True)

    image2 = self.app.inputs.create_image_from_url(url=urls[0] + ' ', allow_duplicate_url=True)
    self.assertEqual(image.url, urls[0])
    self.assertEqual(len(image.input_id) in [22, 32], True)

    self.app.inputs.delete(input_id=image.input_id)
    self.app.inputs.delete(input_id=image2.input_id)

  def test_post_get_delete_image(self):
    """ add image, fetch it, and delete it """

    image = self.app.inputs.create_image_from_url(url=urls[0], allow_duplicate_url=True)
    self.assertEqual(image.url, urls[0])
    self.assertEqual(len(image.input_id) in [22, 32], True)

    image2 = self.app.inputs.get(input_id=image.input_id)
    self.assertEqual(image2.input_id, image.input_id)

    self.app.inputs.delete(input_id=image2.input_id)

  def test_delete_multiple_image(self):
    """ add a few and delete them all with bulk """
    img1 = self.app.inputs.create_image_from_url(url=urls[1], allow_duplicate_url=True)
    self.assertEqual(img1.url, urls[1])

    img2 = self.app.inputs.create_image_from_url(url=urls[2], allow_duplicate_url=True)
    self.assertEqual(img2.url, urls[2])

    img3 = self.app.inputs.create_image_from_url(url=urls[3], allow_duplicate_url=True)
    self.assertEqual(img3.url, urls[3])

    ret = self.app.inputs.delete(input_id=[img1.input_id, img2.input_id, img3.input_id])
    time.sleep(3)

  def test_post_bulk_images(self):
    """ post bulk post images """
    img1 = ClarifaiImage(url=urls[0], concepts=['train', 'railway'], allow_dup_url=True)
    img2 = ClarifaiImage(
        url=urls[1], concepts=['wedding'], not_concepts=['food'], allow_dup_url=True)
    ret_imgs = self.app.inputs.bulk_create_images([img1, img2])

    self.assertEqual(len(list(ret_imgs)), 2)
    # sleep here to ensure inputs are all properly added before deleting them
    time.sleep(2)

    for img in ret_imgs:
      self.assertTrue(isinstance(img, ClarifaiImage))
      try:
        self.app.inputs.delete(img.input_id)
      except ApiError:
        pass

  def test_post_dup_url_with_check(self):
    """ by default the dup url check is enabled, the dup url will be rejected """
    image_id = uuid.uuid4().hex
    img1 = self.app.inputs.create_image_from_url(
        image_id=image_id, url=urls[0], allow_duplicate_url=True)

    with self.assertRaises(ApiError):
      image_id = uuid.uuid4().hex
      img2 = self.app.inputs.create_image_from_url(
          image_id=image_id, url=urls[0], allow_duplicate_url=False)

    self.app.inputs.delete(img1.input_id)

  def test_post_dup_url_without_check(self):
    """ we can skip the dup checking """

    image_id = uuid.uuid4().hex
    img1 = self.app.inputs.create_image_from_url(
        image_id=image_id, url=urls[0], allow_duplicate_url=True)

    image_id = uuid.uuid4().hex
    img2 = self.app.inputs.create_image_from_url(
        image_id=image_id, url=urls[0], allow_duplicate_url=True)

    image_id = uuid.uuid4().hex
    img3 = self.app.inputs.create_image_from_url(
        image_id=image_id, url=urls[0], allow_duplicate_url=True)

    self.app.inputs.delete(img1.input_id)
    self.app.inputs.delete(img2.input_id)
    self.app.inputs.delete(img3.input_id)

  def test_post_cropped_image(self):
    """ add cropped image """

    image = self.app.inputs.create_image_from_url(
        url=urls[0], crop=[0.2, 0.4, 0.3, 0.6], allow_duplicate_url=True)
    self.assertEqual(image.url, urls[0])
    self.assertEqual(len(image.input_id) in [22, 32], True)

    image2 = self.app.inputs.get(input_id=image.input_id)
    self.assertEqual(image2.input_id, image.input_id)

    self.app.inputs.delete(input_id=image2.input_id)

  def test_post_image_with_id(self):
    """ add image with id """

    image_id = uuid.uuid4().hex
    res = self.app.inputs.create_image_from_url(
        image_id=image_id, url=urls[0], crop=[0.2, 0.4, 0.3, 0.6], allow_duplicate_url=True)

    self.assertTrue(isinstance(res, ClarifaiImage))
    self.assertEqual(res.input_id, image_id)

    res2 = self.app.inputs.get(image_id)
    self.assertEqual(res.input_id, res2.input_id)

    self.app.inputs.delete(res2.input_id)

  def test_post_image_with_tags(self):
    """ add image with tags """

    image_id = uuid.uuid4().hex

    img = self.app.inputs.create_image_from_url(
        url=urls[0],
        concepts=['aa1', 'aa2'],
        not_concepts=['bb1', 'bb2'],
        image_id=image_id,
        allow_duplicate_url=True)

    res = self.app.inputs.get(image_id)
    self.assertTrue(isinstance(res, ClarifaiImage))
    self.assertEqual(image_id, res.input_id)

    self.app.inputs.delete(image_id)

  def test_post_image_with_metadata(self):
    """ add image with meta data, retrieve it and compare the meta data """

    image_id = uuid.uuid4().hex
    meta = {
        'myid': image_id,
        'key2': {
            'key3': 4,
            'key4#$!': True,
        }
    }

    self.app.inputs.create_image_from_url(
        url=urls[0], metadata=meta, image_id=image_id, allow_duplicate_url=True)
    try:
      res = self.app.inputs.get(image_id)
    finally:
      self.app.inputs.delete(image_id)

    self.assertTrue(isinstance(res, ClarifaiImage))
    self.assertEqual(image_id, res.input_id)
    self.assertEqual(meta, res.metadata)

  def test_post_image_with_geo(self):
    """ add image with geo info, retrieve it and compare the meta data """

    image_id = uuid.uuid4().hex
    geo = Geo(GeoPoint(-30, 40))
    img = self.app.inputs.create_image_from_url(
        url=urls[0], geo=geo, image_id=image_id, allow_duplicate_url=True)

    res = self.app.inputs.get(image_id)
    self.assertTrue(isinstance(res, ClarifaiImage))
    self.assertEqual(image_id, res.input_id)

    geo_res = res.geo
    self.assertAlmostEqual(geo_res.geo_point.longitude, -30, delta=0.0001)
    self.assertAlmostEqual(geo_res.geo_point.latitude, 40, delta=0.0001)

    self.app.inputs.delete(image_id)

  def test_post_image_with_geo_and_metadata(self):
    """ add image with geo info, retrieve it and compare the meta data """

    image_id = uuid.uuid4().hex
    geo = Geo(GeoPoint(-30, 40))
    meta = {'myid': image_id, 'key_id': 'test_meta'}

    img = self.app.inputs.create_image_from_url(
        url=urls[0], geo=geo, metadata=meta, image_id=image_id, allow_duplicate_url=True)

    res = self.app.inputs.get(image_id)
    self.assertTrue(isinstance(res, ClarifaiImage))
    self.assertEqual(image_id, res.input_id)

    geo_res = res.geo
    self.assertTrue(isinstance(geo_res, Geo))
    self.assertAlmostEqual(geo_res.geo_point.longitude, -30, delta=0.0001)
    self.assertAlmostEqual(geo_res.geo_point.latitude, 40, delta=0.0001)

    self.assertEqual(meta, res.metadata)

    self.app.inputs.delete(image_id)

  def test_post_images_url(self):
    """ upload images from url """

    # upload by url
    img = self.app.inputs.create_image_from_url(urls[0], allow_duplicate_url=True)
    self.assertEqual(img.url, urls[0])
    img_ret = self.app.inputs.get(input_id=img.input_id)
    self.assertEqual(img_ret.url, img.url)
    self.app.inputs.delete(img.input_id)

  def test_post_images_filename(self):
    """ upload images from filename """

    # upload by filename
    img = self.app.inputs.create_image_from_filename(_data_filename('tahoe.jpg'))
    self.assertTrue(img.url.startswith("https://s3.amazonaws.com/clarifai-api/img"))
    img_ret = self.app.inputs.get(input_id=img.input_id)
    self.assertEqual(img_ret.url, img.url)
    self.app.inputs.delete(img.input_id)

  def test_post_images_bytes(self):
    """ upload images from bytes """

    # upload by bytes
    with open(_data_filename('tahoe.jpg'), 'rb') as f:
      file_bytes = f.read()
    img = self.app.inputs.create_image_from_bytes(file_bytes)
    self.assertTrue(img.url.startswith("https://s3.amazonaws.com/clarifai-api/img"))
    img_ret = self.app.inputs.get(input_id=img.input_id)
    self.assertEqual(img_ret.url, img.url)
    self.app.inputs.delete(img.input_id)

  def test_post_images_base64(self):
    """ upload images from base64 """

    # upload by base64 bytes
    with open(_data_filename('tahoe.jpg'), 'rb') as f:
      file_bytes = f.read()
    base64_bytes = base64.b64encode(file_bytes)
    img = self.app.inputs.create_image_from_base64(base64_bytes)
    self.assertTrue(img.url.startswith("https://s3.amazonaws.com/clarifai-api/img"))
    img_ret = self.app.inputs.get(input_id=img.input_id)
    self.assertEqual(img_ret.url, img.url)
    self.app.inputs.delete(img.input_id)

  def test_check_status(self):
    """ check process status """
    counts = self.app.inputs.check_status()
    counts.dict()

  def test_delete_all_images(self):
    """ test delete all images and verify the input count """
    # ret = self.app.inputs.delete_all()
    # time.sleep(5)
    # FIXME(robert): this has to be tested in a separate app

  def test_patch_metadata(self):
    """ test patching metadata """

    # add an image without label
    img = self.app.inputs.create_image_from_url(url=urls[0], allow_duplicate_url=True)
    self.assertTrue(isinstance(img, ClarifaiImage))
    self.assertEqual(img.url, urls[0])

    # patch with metadata (adding first)
    img_res = self.app.inputs.merge_metadata(
        input_id=img.input_id, metadata={
            u'key1': 123,
            u'key2': 234
        })
    self.assertDictEqual(img_res.metadata, {u'key1': 123, u'key2': 234})

    # patch with metadata (merge)
    img_res = self.app.inputs.merge_metadata(
        input_id=img.input_id, metadata={
            u'key3': 345,
            u'key4': 456
        })
    self.assertDictContainsSubset({u'key1': 123, u'key2': 234}, img_res.metadata)
    self.assertDictContainsSubset({u'key3': 345, u'key4': 456}, img_res.metadata)

    # patch with metadata (merge)
    img_res = self.app.inputs.merge_metadata(
        input_id=img.input_id, metadata={
            u'key3': 345,
            u'key4': 456
        })
    self.assertDictContainsSubset({u'key1': 123, u'key2': 234}, img_res.metadata)
    self.assertDictContainsSubset({u'key3': 345, u'key4': 456}, img_res.metadata)

    # delete image
    self.app.inputs.delete(img.input_id)

  def test_image_concepts_applied_correctly(self):
    """ concepts and not_concepts should be applied correctly in create_image """

    img = self.app.inputs.create_image_from_url(
        url=urls[0],
        concepts=['cat', 'animal'],
        not_concepts=['vehicle'],
        allow_duplicate_url=True)
    self.assertSetEqual(set(img.concepts), {'cat', 'animal'})
    self.assertSetEqual(set(img.not_concepts), {'vehicle'})

    self.app.inputs.delete(img.input_id)

  def test_patch_image(self):
    """ update concepts for an image """

    # add an image without label
    img = self.app.inputs.create_image_from_url(url=urls[0], allow_duplicate_url=True)
    self.assertTrue(isinstance(img, ClarifaiImage))
    self.assertEqual(img.url, urls[0])

    img2 = self.app.inputs.get(input_id=img.input_id)
    self.assertTrue(isinstance(img2, ClarifaiImage))

    img3 = self.app.inputs.create_image_from_url(url=urls[1], allow_duplicate_url=True)
    self.assertTrue(isinstance(img, ClarifaiImage))
    self.assertEqual(img3.url, urls[1])

    # add tags
    res3 = self.app.inputs.merge_concepts(
        input_id=img.input_id, concepts=['cat', 'animal'], not_concepts=['vehicle'])
    self.assertTrue(isinstance(res3, ClarifaiImage))
    self.assertSetEqual(set(res3.concepts), {'cat', 'animal'})

    # overwrite tags
    res3 = self.app.inputs.merge_concepts(
        input_id=img.input_id,
        concepts=['dog', 'animal'],
        not_concepts=['vehicle'],
        overwrite=True)
    self.assertTrue(isinstance(res3, ClarifaiImage))
    # input_new = self.app.inputs.get(res3.input_id)
    # self.assertSetEqual(set(input_new.concepts), {'dog', 'animal'})

    # delete tags
    res3 = self.app.inputs.delete_concepts(input_id=img.input_id, concepts=['animal'])
    self.assertTrue(isinstance(res3, ClarifaiImage))
    # self.assertSetEqual(set(res3.concepts), {'dog'})

    # bulk merge tags
    res3 = self.app.inputs.bulk_merge_concepts([img.input_id, img3.input_id],
                                               [[('cat', True),
                                                 ('animal', False)], [('vehicle', False)]])
    self.assertTrue(isinstance(res3, list))
    self.assertTrue(all([isinstance(one, ClarifaiImage) for one in res3]))
    # self.assertSetEqual(set(res3[0].concepts), {'cat', 'dog'})
    # self.assertSetEqual(set(res3[0].not_concepts), {'animal'})
    # self.assertSetEqual(set(res3[1].not_concepts), {'vehicle'})

    # bulk delete tags
    res3 = self.app.inputs.bulk_delete_concepts([img.input_id, img3.input_id],
                                                [['cat', 'animal'], ['vehicle']])
    self.assertTrue(isinstance(res3, list))
    self.assertTrue(all([isinstance(one, ClarifaiImage) for one in res3]))

    # delete image
    self.app.inputs.delete(img2.input_id)
    self.app.inputs.delete(img3.input_id)

  def test_user_errors(self):
    with self.assertRaises(UserError):
      ClarifaiImage(url="blah", file_obj="hey")
    with self.assertRaises(UserError):  # not using open('rb')
      ClarifaiImage(file_obj=open(_data_filename('toddler-flowers.jpeg'), mode='r'))

  def test_base64_from_fileobj(self):

    # send it from a remote url
    data = self.app.api.session.get(urls[0]).content

    image = self.app.inputs.create_image(ClarifaiImage(file_obj=BytesIO(data)))
    self.assertEqual(len(image.input_id) in [22, 32], True)
    self.assertTrue(image.url.startswith("https://s3.amazonaws.com/clarifai-api/img"))

    res2 = self.app.inputs.get(input_id=image.input_id)
    self.assertEqual(image.input_id, res2.input_id)

  def test_base64_from_pil(self):

    # Send it from PIL image buffer
    imgurl = 'https://samples.clarifai.com/metro-north.jpg'
    imgbytes = self.app.api.session.get(imgurl).content

    res = self.app.inputs.create_image_from_bytes(imgbytes)
    self.assertTrue(isinstance(res, ClarifaiImage))
    self.assertEqual(len(res.input_id) in [22, 32], True)
    self.assertTrue(res.url.startswith("https://s3.amazonaws.com/clarifai-api/img"))

    res2 = self.app.inputs.get(input_id=res.input_id)
    self.assertEqual(res.input_id, res2.input_id)

  def not_TSET_csv_images(self):
    """ Test csv image """
    res = self.api.add_inputs_file(
        BytesIO(
            'https://samples.clarifai.com/metro-north.jpg\nhttps://samples.clarifai.com/logo.jpg'),
        'csv')
    self.assertEqual(len(res['inputs']), 2)
    self.assertEqual(res['inputs'][0]['url'], 'https://samples.clarifai.com/metro-north.jpg')
    self.assertEqual(res['inputs'][1]['url'], 'https://samples.clarifai.com/logo.jpg')
    self.to_cleanup.append(res['inputs'][0]['id'])
    self.to_cleanup.append(res['inputs'][1]['id'])

    res3 = self.api.get_inputs()
    self.assertGreaterEqual(len(res3['inputs']), 0)

    res2 = self.api.get_input(input_id=res['inputs'][0]['id'])
    self.assertEqual(res['inputs'][0]['id'], res2['image']['id'])
    res2 = self.api.get_input(input_id=res['inputs'][1]['id'])
    self.assertEqual(res['inputs'][1]['id'], res2['image']['id'])

  def test_partial_errors(self):
    """ upload a few failed urls and fetch by pages
        make sure the partial error is coming and well handled
    """

    img1 = ClarifaiImage(url='https://samples.clarifai.com/dog2.jpeg', allow_dup_url=True)
    img2 = ClarifaiImage(url='https://samples.clarifai.com/dog2_bad.jpeg', allow_dup_url=True)

    imgs = self.app.inputs.bulk_create_images([img1] * 5 + [img2] * 2 + [img1] * 5)
    bad_ids = []
    for img in imgs:
      if img.url == 'https://samples.clarifai.com/dog2_bad.jpeg':
        bad_ids.append(img.input_id)
    self.assertEqual(len(bad_ids), 2)

    self.app.wait_until_inputs_upload_finish(max_wait=30)

    # Mixed status exception will be raised
    found_error = False
    found_error_id = False
    for img_one in self.app.inputs.get_all():
      if img_one.status.code != 30000:
        found_error = True
        if img_one.input_id in bad_ids:
          found_error_id = True
    self.assertTrue(found_error)
    self.assertTrue(found_error_id)

    # no exception will be raised by default
    found_error = False
    for img_one in self.app.inputs.get_all(ignore_error=True):
      if img_one.status.code != 30000:
        found_error = True
    self.assertFalse(found_error)


if __name__ == '__main__':
  unittest.main()



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/clarifai/api/model_version.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from clarifai.rest.grpc.proto.clarifai.api import common_pb2 as proto_dot_clarifai_dot_api_dot_common__pb2
from clarifai.rest.grpc.proto.clarifai.api import concept_pb2 as proto_dot_clarifai_dot_api_dot_concept__pb2
from clarifai.rest.grpc.proto.clarifai.api.status import status_pb2 as proto_dot_clarifai_dot_api_dot_status_dot_status__pb2
from clarifai.rest.grpc.proto.clarifai.api.utils import extensions_pb2 as proto_dot_clarifai_dot_api_dot_utils_dot_extensions__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/clarifai/api/model_version.proto',
  package='clarifai.api',
  syntax='proto3',
  serialized_pb=_b('\n&proto/clarifai/api/model_version.proto\x12\x0c\x63larifai.api\x1a\x1fproto/clarifai/api/common.proto\x1a proto/clarifai/api/concept.proto\x1a&proto/clarifai/api/status/status.proto\x1a)proto/clarifai/api/utils/extensions.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa2\x02\n\x0cModelVersion\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x06status\x18\x03 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12\x1c\n\x14\x61\x63tive_concept_count\x18\x04 \x01(\r\x12*\n\x07metrics\x18\x05 \x01(\x0b\x32\x19.clarifai.api.EvalMetrics\x12\x19\n\x11total_input_count\x18\x06 \x01(\r\x12\x44\n\x17pretrained_model_config\x18\x07 \x01(\x0b\x32#.clarifai.api.PretrainedModelConfig\"1\n\x15PretrainedModelConfig\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"o\n\x16GetModelVersionRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x12\n\nversion_id\x18\x03 \x01(\t\"\x92\x01\n\x18ListModelVersionsRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\r\x12\x10\n\x08per_page\x18\x04 \x01(\r\x12\x13\n\x0b\x63oncept_ids\x18\x05 \x03(\t\"\x91\x01\n\x18PostModelVersionsRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x32\n\x0emodel_versions\x18\x03 \x03(\x0b\x32\x1a.clarifai.api.ModelVersion\"r\n\x19\x44\x65leteModelVersionRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x10\n\x08model_id\x18\x03 \x01(\t\x12\x12\n\nversion_id\x18\x04 \x01(\t\"|\n\x1aSingleModelVersionResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12\x31\n\rmodel_version\x18\x02 \x01(\x0b\x32\x1a.clarifai.api.ModelVersion\"\x82\x01\n\x19MultiModelVersionResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12\x38\n\x0emodel_versions\x18\x02 \x03(\x0b\x32\x1a.clarifai.api.ModelVersionB\x04\x80\xb5\x18\x01\"1\n\nLabelCount\x12\x14\n\x0c\x63oncept_name\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\r\"L\n\x11LabelDistribution\x12\x37\n\x15positive_label_counts\x18\x01 \x03(\x0b\x32\x18.clarifai.api.LabelCount\"B\n\x17\x43ooccurrenceMatrixEntry\x12\x0b\n\x03row\x18\x01 \x01(\t\x12\x0b\n\x03\x63ol\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\r\"`\n\x12\x43ooccurrenceMatrix\x12\x35\n\x06matrix\x18\x01 \x03(\x0b\x32%.clarifai.api.CooccurrenceMatrixEntry\x12\x13\n\x0b\x63oncept_ids\x18\x02 \x03(\t\"H\n\x14\x43onfusionMatrixEntry\x12\x11\n\tpredicted\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tual\x18\x02 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\x02\"Z\n\x0f\x43onfusionMatrix\x12\x32\n\x06matrix\x18\x01 \x03(\x0b\x32\".clarifai.api.ConfusionMatrixEntry\x12\x13\n\x0b\x63oncept_ids\x18\x02 \x03(\t\"3\n\x03ROC\x12\x0b\n\x03\x66pr\x18\x01 \x03(\x02\x12\x0b\n\x03tpr\x18\x02 \x03(\x02\x12\x12\n\nthresholds\x18\x03 \x03(\x02\"M\n\x14PrecisionRecallCurve\x12\x0e\n\x06recall\x18\x01 \x03(\x02\x12\x11\n\tprecision\x18\x02 \x03(\x02\x12\x12\n\nthresholds\x18\x03 \x03(\x02\"\xf1\x01\n\rBinaryMetrics\x12\x0f\n\x07num_pos\x18\x01 \x01(\r\x12\x0f\n\x07num_neg\x18\x02 \x01(\r\x12\x0f\n\x07num_tot\x18\x03 \x01(\r\x12\x0f\n\x07roc_auc\x18\x04 \x01(\x02\x12\n\n\x02\x66\x31\x18\x05 \x01(\x02\x12&\n\x07\x63oncept\x18\x06 \x01(\x0b\x32\x15.clarifai.api.Concept\x12$\n\troc_curve\x18\x07 \x01(\x0b\x32\x11.clarifai.api.ROC\x12\x42\n\x16precision_recall_curve\x18\x08 \x01(\x0b\x32\".clarifai.api.PrecisionRecallCurve\"\x94\x01\n\x10\x45valTestSetEntry\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x31\n\x12predicted_concepts\x18\x03 \x03(\x0b\x32\x15.clarifai.api.Concept\x12\x34\n\x15ground_truth_concepts\x18\x04 \x03(\x0b\x32\x15.clarifai.api.Concept\"\xeb\x01\n\x0eMetricsSummary\x12\x19\n\rtop1_accuracy\x18\x01 \x01(\x02\x42\x02\x18\x01\x12\x19\n\rtop5_accuracy\x18\x02 \x01(\x02\x42\x02\x18\x01\x12\x19\n\x11macro_avg_roc_auc\x18\x03 \x01(\x02\x12\x19\n\x11macro_std_roc_auc\x18\x04 \x01(\x02\x12\x1a\n\x12macro_avg_f1_score\x18\x05 \x01(\x02\x12\x1a\n\x12macro_std_f1_score\x18\x06 \x01(\x02\x12\x1b\n\x13macro_avg_precision\x18\x07 \x01(\x02\x12\x18\n\x10macro_avg_recall\x18\x08 \x01(\x02\"\xff\x02\n\x0b\x45valMetrics\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12-\n\x07summary\x18\x02 \x01(\x0b\x32\x1c.clarifai.api.MetricsSummary\x12\x37\n\x10\x63onfusion_matrix\x18\x03 \x01(\x0b\x32\x1d.clarifai.api.ConfusionMatrix\x12=\n\x13\x63ooccurrence_matrix\x18\x04 \x01(\x0b\x32 .clarifai.api.CooccurrenceMatrix\x12\x35\n\x0clabel_counts\x18\x05 \x01(\x0b\x32\x1f.clarifai.api.LabelDistribution\x12\x33\n\x0e\x62inary_metrics\x18\x06 \x03(\x0b\x32\x1b.clarifai.api.BinaryMetrics\x12\x30\n\x08test_set\x18\x07 \x03(\x0b\x32\x1e.clarifai.api.EvalTestSetEntry\"\xc6\x02\n\x1dGetModelVersionMetricsRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x12\n\nversion_id\x18\x03 \x01(\t\x12G\n\x06\x66ields\x18\x04 \x01(\x0b\x32\x37.clarifai.api.GetModelVersionMetricsRequest.FieldsValue\x1a\x84\x01\n\x0b\x46ieldsValue\x12\x18\n\x10\x63onfusion_matrix\x18\x01 \x01(\x08\x12\x1b\n\x13\x63ooccurrence_matrix\x18\x02 \x01(\x08\x12\x14\n\x0clabel_counts\x18\x03 \x01(\x08\x12\x16\n\x0e\x62inary_metrics\x18\x04 \x01(\x08\x12\x10\n\x08test_set\x18\x05 \x01(\x08\"\x8d\x01\n\x1ePostModelVersionMetricsRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x12\n\nversion_id\x18\x03 \x01(\t\x12\x14\n\x0cmax_examples\x18\x04 \x01(\rB$Z\x03\x61pi\xa2\x02\x04\x43\x41IP\xc2\x02\x01_\xca\x02\x11\x43larifai\\Internalb\x06proto3')
  ,
  dependencies=[proto_dot_clarifai_dot_api_dot_common__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_concept__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_utils_dot_extensions__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_MODELVERSION = _descriptor.Descriptor(
  name='ModelVersion',
  full_name='clarifai.api.ModelVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='clarifai.api.ModelVersion.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='clarifai.api.ModelVersion.created_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.ModelVersion.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active_concept_count', full_name='clarifai.api.ModelVersion.active_concept_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='clarifai.api.ModelVersion.metrics', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_input_count', full_name='clarifai.api.ModelVersion.total_input_count', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pretrained_model_config', full_name='clarifai.api.ModelVersion.pretrained_model_config', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=240,
  serialized_end=530,
)


_PRETRAINEDMODELCONFIG = _descriptor.Descriptor(
  name='PretrainedModelConfig',
  full_name='clarifai.api.PretrainedModelConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='clarifai.api.PretrainedModelConfig.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='clarifai.api.PretrainedModelConfig.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=532,
  serialized_end=581,
)


_GETMODELVERSIONREQUEST = _descriptor.Descriptor(
  name='GetModelVersionRequest',
  full_name='clarifai.api.GetModelVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.GetModelVersionRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='clarifai.api.GetModelVersionRequest.model_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version_id', full_name='clarifai.api.GetModelVersionRequest.version_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=583,
  serialized_end=694,
)


_LISTMODELVERSIONSREQUEST = _descriptor.Descriptor(
  name='ListModelVersionsRequest',
  full_name='clarifai.api.ListModelVersionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.ListModelVersionsRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='clarifai.api.ListModelVersionsRequest.model_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page', full_name='clarifai.api.ListModelVersionsRequest.page', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='per_page', full_name='clarifai.api.ListModelVersionsRequest.per_page', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept_ids', full_name='clarifai.api.ListModelVersionsRequest.concept_ids', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=697,
  serialized_end=843,
)


_POSTMODELVERSIONSREQUEST = _descriptor.Descriptor(
  name='PostModelVersionsRequest',
  full_name='clarifai.api.PostModelVersionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.PostModelVersionsRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='clarifai.api.PostModelVersionsRequest.model_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_versions', full_name='clarifai.api.PostModelVersionsRequest.model_versions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=846,
  serialized_end=991,
)


_DELETEMODELVERSIONREQUEST = _descriptor.Descriptor(
  name='DeleteModelVersionRequest',
  full_name='clarifai.api.DeleteModelVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.DeleteModelVersionRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='clarifai.api.DeleteModelVersionRequest.model_id', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version_id', full_name='clarifai.api.DeleteModelVersionRequest.version_id', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=993,
  serialized_end=1107,
)


_SINGLEMODELVERSIONRESPONSE = _descriptor.Descriptor(
  name='SingleModelVersionResponse',
  full_name='clarifai.api.SingleModelVersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.SingleModelVersionResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_version', full_name='clarifai.api.SingleModelVersionResponse.model_version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1109,
  serialized_end=1233,
)


_MULTIMODELVERSIONRESPONSE = _descriptor.Descriptor(
  name='MultiModelVersionResponse',
  full_name='clarifai.api.MultiModelVersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.MultiModelVersionResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_versions', full_name='clarifai.api.MultiModelVersionResponse.model_versions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1236,
  serialized_end=1366,
)


_LABELCOUNT = _descriptor.Descriptor(
  name='LabelCount',
  full_name='clarifai.api.LabelCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='concept_name', full_name='clarifai.api.LabelCount.concept_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='clarifai.api.LabelCount.count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1368,
  serialized_end=1417,
)


_LABELDISTRIBUTION = _descriptor.Descriptor(
  name='LabelDistribution',
  full_name='clarifai.api.LabelDistribution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='positive_label_counts', full_name='clarifai.api.LabelDistribution.positive_label_counts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1419,
  serialized_end=1495,
)


_COOCCURRENCEMATRIXENTRY = _descriptor.Descriptor(
  name='CooccurrenceMatrixEntry',
  full_name='clarifai.api.CooccurrenceMatrixEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='row', full_name='clarifai.api.CooccurrenceMatrixEntry.row', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='col', full_name='clarifai.api.CooccurrenceMatrixEntry.col', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='clarifai.api.CooccurrenceMatrixEntry.count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1497,
  serialized_end=1563,
)


_COOCCURRENCEMATRIX = _descriptor.Descriptor(
  name='CooccurrenceMatrix',
  full_name='clarifai.api.CooccurrenceMatrix',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matrix', full_name='clarifai.api.CooccurrenceMatrix.matrix', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept_ids', full_name='clarifai.api.CooccurrenceMatrix.concept_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1565,
  serialized_end=1661,
)


_CONFUSIONMATRIXENTRY = _descriptor.Descriptor(
  name='ConfusionMatrixEntry',
  full_name='clarifai.api.ConfusionMatrixEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='predicted', full_name='clarifai.api.ConfusionMatrixEntry.predicted', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='actual', full_name='clarifai.api.ConfusionMatrixEntry.actual', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='clarifai.api.ConfusionMatrixEntry.value', index=2,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1663,
  serialized_end=1735,
)


_CONFUSIONMATRIX = _descriptor.Descriptor(
  name='ConfusionMatrix',
  full_name='clarifai.api.ConfusionMatrix',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='matrix', full_name='clarifai.api.ConfusionMatrix.matrix', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept_ids', full_name='clarifai.api.ConfusionMatrix.concept_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1737,
  serialized_end=1827,
)


_ROC = _descriptor.Descriptor(
  name='ROC',
  full_name='clarifai.api.ROC',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fpr', full_name='clarifai.api.ROC.fpr', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tpr', full_name='clarifai.api.ROC.tpr', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thresholds', full_name='clarifai.api.ROC.thresholds', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1829,
  serialized_end=1880,
)


_PRECISIONRECALLCURVE = _descriptor.Descriptor(
  name='PrecisionRecallCurve',
  full_name='clarifai.api.PrecisionRecallCurve',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recall', full_name='clarifai.api.PrecisionRecallCurve.recall', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='precision', full_name='clarifai.api.PrecisionRecallCurve.precision', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thresholds', full_name='clarifai.api.PrecisionRecallCurve.thresholds', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1882,
  serialized_end=1959,
)


_BINARYMETRICS = _descriptor.Descriptor(
  name='BinaryMetrics',
  full_name='clarifai.api.BinaryMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_pos', full_name='clarifai.api.BinaryMetrics.num_pos', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_neg', full_name='clarifai.api.BinaryMetrics.num_neg', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_tot', full_name='clarifai.api.BinaryMetrics.num_tot', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='roc_auc', full_name='clarifai.api.BinaryMetrics.roc_auc', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='f1', full_name='clarifai.api.BinaryMetrics.f1', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept', full_name='clarifai.api.BinaryMetrics.concept', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='roc_curve', full_name='clarifai.api.BinaryMetrics.roc_curve', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='precision_recall_curve', full_name='clarifai.api.BinaryMetrics.precision_recall_curve', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1962,
  serialized_end=2203,
)


_EVALTESTSETENTRY = _descriptor.Descriptor(
  name='EvalTestSetEntry',
  full_name='clarifai.api.EvalTestSetEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='clarifai.api.EvalTestSetEntry.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url', full_name='clarifai.api.EvalTestSetEntry.url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='predicted_concepts', full_name='clarifai.api.EvalTestSetEntry.predicted_concepts', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ground_truth_concepts', full_name='clarifai.api.EvalTestSetEntry.ground_truth_concepts', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2206,
  serialized_end=2354,
)


_METRICSSUMMARY = _descriptor.Descriptor(
  name='MetricsSummary',
  full_name='clarifai.api.MetricsSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='top1_accuracy', full_name='clarifai.api.MetricsSummary.top1_accuracy', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='top5_accuracy', full_name='clarifai.api.MetricsSummary.top5_accuracy', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='macro_avg_roc_auc', full_name='clarifai.api.MetricsSummary.macro_avg_roc_auc', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='macro_std_roc_auc', full_name='clarifai.api.MetricsSummary.macro_std_roc_auc', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='macro_avg_f1_score', full_name='clarifai.api.MetricsSummary.macro_avg_f1_score', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='macro_std_f1_score', full_name='clarifai.api.MetricsSummary.macro_std_f1_score', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='macro_avg_precision', full_name='clarifai.api.MetricsSummary.macro_avg_precision', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='macro_avg_recall', full_name='clarifai.api.MetricsSummary.macro_avg_recall', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2357,
  serialized_end=2592,
)


_EVALMETRICS = _descriptor.Descriptor(
  name='EvalMetrics',
  full_name='clarifai.api.EvalMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.EvalMetrics.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary', full_name='clarifai.api.EvalMetrics.summary', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='confusion_matrix', full_name='clarifai.api.EvalMetrics.confusion_matrix', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cooccurrence_matrix', full_name='clarifai.api.EvalMetrics.cooccurrence_matrix', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_counts', full_name='clarifai.api.EvalMetrics.label_counts', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binary_metrics', full_name='clarifai.api.EvalMetrics.binary_metrics', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='test_set', full_name='clarifai.api.EvalMetrics.test_set', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2595,
  serialized_end=2978,
)


_GETMODELVERSIONMETRICSREQUEST_FIELDSVALUE = _descriptor.Descriptor(
  name='FieldsValue',
  full_name='clarifai.api.GetModelVersionMetricsRequest.FieldsValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='confusion_matrix', full_name='clarifai.api.GetModelVersionMetricsRequest.FieldsValue.confusion_matrix', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cooccurrence_matrix', full_name='clarifai.api.GetModelVersionMetricsRequest.FieldsValue.cooccurrence_matrix', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_counts', full_name='clarifai.api.GetModelVersionMetricsRequest.FieldsValue.label_counts', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binary_metrics', full_name='clarifai.api.GetModelVersionMetricsRequest.FieldsValue.binary_metrics', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='test_set', full_name='clarifai.api.GetModelVersionMetricsRequest.FieldsValue.test_set', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3175,
  serialized_end=3307,
)

_GETMODELVERSIONMETRICSREQUEST = _descriptor.Descriptor(
  name='GetModelVersionMetricsRequest',
  full_name='clarifai.api.GetModelVersionMetricsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.GetModelVersionMetricsRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='clarifai.api.GetModelVersionMetricsRequest.model_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version_id', full_name='clarifai.api.GetModelVersionMetricsRequest.version_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fields', full_name='clarifai.api.GetModelVersionMetricsRequest.fields', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GETMODELVERSIONMETRICSREQUEST_FIELDSVALUE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2981,
  serialized_end=3307,
)


_POSTMODELVERSIONMETRICSREQUEST = _descriptor.Descriptor(
  name='PostModelVersionMetricsRequest',
  full_name='clarifai.api.PostModelVersionMetricsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.PostModelVersionMetricsRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='clarifai.api.PostModelVersionMetricsRequest.model_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version_id', full_name='clarifai.api.PostModelVersionMetricsRequest.version_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_examples', full_name='clarifai.api.PostModelVersionMetricsRequest.max_examples', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3310,
  serialized_end=3451,
)

_MODELVERSION.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MODELVERSION.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_MODELVERSION.fields_by_name['metrics'].message_type = _EVALMETRICS
_MODELVERSION.fields_by_name['pretrained_model_config'].message_type = _PRETRAINEDMODELCONFIG
_GETMODELVERSIONREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_LISTMODELVERSIONSREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_POSTMODELVERSIONSREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_POSTMODELVERSIONSREQUEST.fields_by_name['model_versions'].message_type = _MODELVERSION
_DELETEMODELVERSIONREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_SINGLEMODELVERSIONRESPONSE.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_SINGLEMODELVERSIONRESPONSE.fields_by_name['model_version'].message_type = _MODELVERSION
_MULTIMODELVERSIONRESPONSE.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_MULTIMODELVERSIONRESPONSE.fields_by_name['model_versions'].message_type = _MODELVERSION
_LABELDISTRIBUTION.fields_by_name['positive_label_counts'].message_type = _LABELCOUNT
_COOCCURRENCEMATRIX.fields_by_name['matrix'].message_type = _COOCCURRENCEMATRIXENTRY
_CONFUSIONMATRIX.fields_by_name['matrix'].message_type = _CONFUSIONMATRIXENTRY
_BINARYMETRICS.fields_by_name['concept'].message_type = proto_dot_clarifai_dot_api_dot_concept__pb2._CONCEPT
_BINARYMETRICS.fields_by_name['roc_curve'].message_type = _ROC
_BINARYMETRICS.fields_by_name['precision_recall_curve'].message_type = _PRECISIONRECALLCURVE
_EVALTESTSETENTRY.fields_by_name['predicted_concepts'].message_type = proto_dot_clarifai_dot_api_dot_concept__pb2._CONCEPT
_EVALTESTSETENTRY.fields_by_name['ground_truth_concepts'].message_type = proto_dot_clarifai_dot_api_dot_concept__pb2._CONCEPT
_EVALMETRICS.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_EVALMETRICS.fields_by_name['summary'].message_type = _METRICSSUMMARY
_EVALMETRICS.fields_by_name['confusion_matrix'].message_type = _CONFUSIONMATRIX
_EVALMETRICS.fields_by_name['cooccurrence_matrix'].message_type = _COOCCURRENCEMATRIX
_EVALMETRICS.fields_by_name['label_counts'].message_type = _LABELDISTRIBUTION
_EVALMETRICS.fields_by_name['binary_metrics'].message_type = _BINARYMETRICS
_EVALMETRICS.fields_by_name['test_set'].message_type = _EVALTESTSETENTRY
_GETMODELVERSIONMETRICSREQUEST_FIELDSVALUE.containing_type = _GETMODELVERSIONMETRICSREQUEST
_GETMODELVERSIONMETRICSREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_GETMODELVERSIONMETRICSREQUEST.fields_by_name['fields'].message_type = _GETMODELVERSIONMETRICSREQUEST_FIELDSVALUE
_POSTMODELVERSIONMETRICSREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
DESCRIPTOR.message_types_by_name['ModelVersion'] = _MODELVERSION
DESCRIPTOR.message_types_by_name['PretrainedModelConfig'] = _PRETRAINEDMODELCONFIG
DESCRIPTOR.message_types_by_name['GetModelVersionRequest'] = _GETMODELVERSIONREQUEST
DESCRIPTOR.message_types_by_name['ListModelVersionsRequest'] = _LISTMODELVERSIONSREQUEST
DESCRIPTOR.message_types_by_name['PostModelVersionsRequest'] = _POSTMODELVERSIONSREQUEST
DESCRIPTOR.message_types_by_name['DeleteModelVersionRequest'] = _DELETEMODELVERSIONREQUEST
DESCRIPTOR.message_types_by_name['SingleModelVersionResponse'] = _SINGLEMODELVERSIONRESPONSE
DESCRIPTOR.message_types_by_name['MultiModelVersionResponse'] = _MULTIMODELVERSIONRESPONSE
DESCRIPTOR.message_types_by_name['LabelCount'] = _LABELCOUNT
DESCRIPTOR.message_types_by_name['LabelDistribution'] = _LABELDISTRIBUTION
DESCRIPTOR.message_types_by_name['CooccurrenceMatrixEntry'] = _COOCCURRENCEMATRIXENTRY
DESCRIPTOR.message_types_by_name['CooccurrenceMatrix'] = _COOCCURRENCEMATRIX
DESCRIPTOR.message_types_by_name['ConfusionMatrixEntry'] = _CONFUSIONMATRIXENTRY
DESCRIPTOR.message_types_by_name['ConfusionMatrix'] = _CONFUSIONMATRIX
DESCRIPTOR.message_types_by_name['ROC'] = _ROC
DESCRIPTOR.message_types_by_name['PrecisionRecallCurve'] = _PRECISIONRECALLCURVE
DESCRIPTOR.message_types_by_name['BinaryMetrics'] = _BINARYMETRICS
DESCRIPTOR.message_types_by_name['EvalTestSetEntry'] = _EVALTESTSETENTRY
DESCRIPTOR.message_types_by_name['MetricsSummary'] = _METRICSSUMMARY
DESCRIPTOR.message_types_by_name['EvalMetrics'] = _EVALMETRICS
DESCRIPTOR.message_types_by_name['GetModelVersionMetricsRequest'] = _GETMODELVERSIONMETRICSREQUEST
DESCRIPTOR.message_types_by_name['PostModelVersionMetricsRequest'] = _POSTMODELVERSIONMETRICSREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ModelVersion = _reflection.GeneratedProtocolMessageType('ModelVersion', (_message.Message,), dict(
  DESCRIPTOR = _MODELVERSION,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.ModelVersion)
  ))
_sym_db.RegisterMessage(ModelVersion)

PretrainedModelConfig = _reflection.GeneratedProtocolMessageType('PretrainedModelConfig', (_message.Message,), dict(
  DESCRIPTOR = _PRETRAINEDMODELCONFIG,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.PretrainedModelConfig)
  ))
_sym_db.RegisterMessage(PretrainedModelConfig)

GetModelVersionRequest = _reflection.GeneratedProtocolMessageType('GetModelVersionRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETMODELVERSIONREQUEST,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.GetModelVersionRequest)
  ))
_sym_db.RegisterMessage(GetModelVersionRequest)

ListModelVersionsRequest = _reflection.GeneratedProtocolMessageType('ListModelVersionsRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTMODELVERSIONSREQUEST,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.ListModelVersionsRequest)
  ))
_sym_db.RegisterMessage(ListModelVersionsRequest)

PostModelVersionsRequest = _reflection.GeneratedProtocolMessageType('PostModelVersionsRequest', (_message.Message,), dict(
  DESCRIPTOR = _POSTMODELVERSIONSREQUEST,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.PostModelVersionsRequest)
  ))
_sym_db.RegisterMessage(PostModelVersionsRequest)

DeleteModelVersionRequest = _reflection.GeneratedProtocolMessageType('DeleteModelVersionRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEMODELVERSIONREQUEST,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.DeleteModelVersionRequest)
  ))
_sym_db.RegisterMessage(DeleteModelVersionRequest)

SingleModelVersionResponse = _reflection.GeneratedProtocolMessageType('SingleModelVersionResponse', (_message.Message,), dict(
  DESCRIPTOR = _SINGLEMODELVERSIONRESPONSE,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.SingleModelVersionResponse)
  ))
_sym_db.RegisterMessage(SingleModelVersionResponse)

MultiModelVersionResponse = _reflection.GeneratedProtocolMessageType('MultiModelVersionResponse', (_message.Message,), dict(
  DESCRIPTOR = _MULTIMODELVERSIONRESPONSE,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.MultiModelVersionResponse)
  ))
_sym_db.RegisterMessage(MultiModelVersionResponse)

LabelCount = _reflection.GeneratedProtocolMessageType('LabelCount', (_message.Message,), dict(
  DESCRIPTOR = _LABELCOUNT,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.LabelCount)
  ))
_sym_db.RegisterMessage(LabelCount)

LabelDistribution = _reflection.GeneratedProtocolMessageType('LabelDistribution', (_message.Message,), dict(
  DESCRIPTOR = _LABELDISTRIBUTION,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.LabelDistribution)
  ))
_sym_db.RegisterMessage(LabelDistribution)

CooccurrenceMatrixEntry = _reflection.GeneratedProtocolMessageType('CooccurrenceMatrixEntry', (_message.Message,), dict(
  DESCRIPTOR = _COOCCURRENCEMATRIXENTRY,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.CooccurrenceMatrixEntry)
  ))
_sym_db.RegisterMessage(CooccurrenceMatrixEntry)

CooccurrenceMatrix = _reflection.GeneratedProtocolMessageType('CooccurrenceMatrix', (_message.Message,), dict(
  DESCRIPTOR = _COOCCURRENCEMATRIX,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.CooccurrenceMatrix)
  ))
_sym_db.RegisterMessage(CooccurrenceMatrix)

ConfusionMatrixEntry = _reflection.GeneratedProtocolMessageType('ConfusionMatrixEntry', (_message.Message,), dict(
  DESCRIPTOR = _CONFUSIONMATRIXENTRY,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.ConfusionMatrixEntry)
  ))
_sym_db.RegisterMessage(ConfusionMatrixEntry)

ConfusionMatrix = _reflection.GeneratedProtocolMessageType('ConfusionMatrix', (_message.Message,), dict(
  DESCRIPTOR = _CONFUSIONMATRIX,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.ConfusionMatrix)
  ))
_sym_db.RegisterMessage(ConfusionMatrix)

ROC = _reflection.GeneratedProtocolMessageType('ROC', (_message.Message,), dict(
  DESCRIPTOR = _ROC,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.ROC)
  ))
_sym_db.RegisterMessage(ROC)

PrecisionRecallCurve = _reflection.GeneratedProtocolMessageType('PrecisionRecallCurve', (_message.Message,), dict(
  DESCRIPTOR = _PRECISIONRECALLCURVE,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.PrecisionRecallCurve)
  ))
_sym_db.RegisterMessage(PrecisionRecallCurve)

BinaryMetrics = _reflection.GeneratedProtocolMessageType('BinaryMetrics', (_message.Message,), dict(
  DESCRIPTOR = _BINARYMETRICS,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.BinaryMetrics)
  ))
_sym_db.RegisterMessage(BinaryMetrics)

EvalTestSetEntry = _reflection.GeneratedProtocolMessageType('EvalTestSetEntry', (_message.Message,), dict(
  DESCRIPTOR = _EVALTESTSETENTRY,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.EvalTestSetEntry)
  ))
_sym_db.RegisterMessage(EvalTestSetEntry)

MetricsSummary = _reflection.GeneratedProtocolMessageType('MetricsSummary', (_message.Message,), dict(
  DESCRIPTOR = _METRICSSUMMARY,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.MetricsSummary)
  ))
_sym_db.RegisterMessage(MetricsSummary)

EvalMetrics = _reflection.GeneratedProtocolMessageType('EvalMetrics', (_message.Message,), dict(
  DESCRIPTOR = _EVALMETRICS,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.EvalMetrics)
  ))
_sym_db.RegisterMessage(EvalMetrics)

GetModelVersionMetricsRequest = _reflection.GeneratedProtocolMessageType('GetModelVersionMetricsRequest', (_message.Message,), dict(

  FieldsValue = _reflection.GeneratedProtocolMessageType('FieldsValue', (_message.Message,), dict(
    DESCRIPTOR = _GETMODELVERSIONMETRICSREQUEST_FIELDSVALUE,
    __module__ = 'proto.clarifai.api.model_version_pb2'
    # @@protoc_insertion_point(class_scope:clarifai.api.GetModelVersionMetricsRequest.FieldsValue)
    ))
  ,
  DESCRIPTOR = _GETMODELVERSIONMETRICSREQUEST,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.GetModelVersionMetricsRequest)
  ))
_sym_db.RegisterMessage(GetModelVersionMetricsRequest)
_sym_db.RegisterMessage(GetModelVersionMetricsRequest.FieldsValue)

PostModelVersionMetricsRequest = _reflection.GeneratedProtocolMessageType('PostModelVersionMetricsRequest', (_message.Message,), dict(
  DESCRIPTOR = _POSTMODELVERSIONMETRICSREQUEST,
  __module__ = 'proto.clarifai.api.model_version_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.PostModelVersionMetricsRequest)
  ))
_sym_db.RegisterMessage(PostModelVersionMetricsRequest)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z\003api\242\002\004CAIP\302\002\001_\312\002\021Clarifai\\Internal'))
_MULTIMODELVERSIONRESPONSE.fields_by_name['model_versions'].has_options = True
_MULTIMODELVERSIONRESPONSE.fields_by_name['model_versions']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001'))
_METRICSSUMMARY.fields_by_name['top1_accuracy'].has_options = True
_METRICSSUMMARY.fields_by_name['top1_accuracy']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_METRICSSUMMARY.fields_by_name['top5_accuracy'].has_options = True
_METRICSSUMMARY.fields_by_name['top5_accuracy']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
# @@protoc_insertion_point(module_scope)
